# PSoC Projects

## USB Bootloader
A generic usbuart bootloader suitable for any usb device.

## USB Bridge
Implements USB audio to I2S stream, an SPI/I2S interface to an external device (fpga), and a USB serial port for communication and configuration.
